AICoachingService class

Constructors

AICoachingService()
factory

Properties

downloadProgress ValueNotifier<double>
final
errorMessage ValueNotifier<String?>
final
hashCode int
The hash code for this object.
no setterinherited
isDownloading ValueNotifier<bool>
final
isReady ValueNotifier<bool>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyzeVideoMovement(List<Map<String, dynamic>> frames) Future<String>
Analyse une séquence de poses issue d'une vidéo
initialize() Future<void>
Initialise le modèle Gemma en mémoire
installGemma3() Future<void>
Installe le modèle Gemma 3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited