DetectedPose class
Represents a detected pose with all its landmarks
Constructors
-
DetectedPose({required List<
PoseLandmarkData> landmarks, required DateTime timestamp}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
landmarks
→ List<
PoseLandmarkData> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
getLandmark(
String type) → PoseLandmarkData? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited