PoseLandmarkData class

Represents a single detected pose landmark (joint point)

Constructors

PoseLandmarkData({required String type, required double x, required double y, double z = 0, double likelihood = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
likelihood double
final
position Offset
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
x double
final
y double
final
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited