ShotDetectionService class

Analyzes the trajectory of the ball relative to the hoop to detect shots. Uses both YOLO action labels (jump-shot, layup) and ball-hoop trajectory for more reliable shot detection.

Constructors

ShotDetectionService()
factory

Properties

attempts int
no setter
hashCode int
The hash code for this object.
no setterinherited
lastPlayerAction String?
The current player action detected by the YOLO model.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update(DetectedObjects? objects) ShotStatus
Update the state with new detection data.

Operators

operator ==(Object other) bool
The equality operator.
inherited