DetectedObjects class
Holds all detected basketball-relevant objects for a single frame
Constructors
- DetectedObjects({DetectedObjectRect? basketball, DetectedObjectRect? hoop, DetectedObjectRect? player, required DateTime timestamp, String modelType = 'none'})
-
const
-
DetectedObjects.fromJson(Map<
String, dynamic> json) -
factory
Properties
- basketball → DetectedObjectRect?
-
final
- hasAny → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoop → DetectedObjectRect?
-
final
- modelType → String
-
The type of detection model used ("yolo_custom" or "none").
final
- player → DetectedObjectRect?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited