NormalizedRect class

Represents a normalized bounding rect 0..1 for a detected object

Constructors

NormalizedRect({required double left, required double top, required double right, required double bottom})
const
NormalizedRect.fromJson(Map<String, dynamic> json)
factory

Properties

bottom double
final
center Offset
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
no setter
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final
width double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited